@@ -21,7 +21,7 @@
 #include <QVBoxLayout>
 
 // KDE Frameworks
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include "kimagemapeditor_debug.h"
 
 
@@ -30,7 +30,7 @@ MapsListView::MapsListView(QWidget *parent)
 
   QVBoxLayout *mainLayout = new QVBoxLayout(this);
   mainLayout->setSpacing(0);
-  mainLayout->setMargin(0);
+  mainLayout->setContentsMargins(0, 0, 0, 0);
 
   _listView = new QTreeWidget(this);
   _listView->setColumnCount(1);
@@ -137,7 +137,7 @@ void MapsListView::changeMapName(const QString & oldName, const QString & newNam
 //        qCDebug(KIMAGEMAPEDITOR_LOG) << "MapsListView::changeMapName : successful";
     }
     else {
-        qCWarning(KIMAGEMAPEDITOR_LOG) << "MapsListView::changeMapName : Chouldn't find map with name '" << oldName << "'";
+        qCWarning(KIMAGEMAPEDITOR_LOG) << "MapsListView::changeMapName : Couldn't find map with name '" << oldName << "'";
     }
 
 }
